@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::TicketOverview::Small;
@@ -16,18 +16,15 @@ use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
-    'Kernel::Language',
     'Kernel::System::Log',
     'Kernel::Output::HTML::Layout',
     'Kernel::System::CustomerUser',
-    'Kernel::System::Group',
     'Kernel::System::User',
     'Kernel::System::JSON',
     'Kernel::System::DynamicField',
     'Kernel::System::Ticket::ColumnFilter',
     'Kernel::System::DynamicField::Backend',
     'Kernel::System::Ticket',
-    'Kernel::System::Ticket::Article',
     'Kernel::System::Main',
 );
 
@@ -44,6 +41,8 @@ sub new {
     # get config object
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
+    $Self->{SmallViewColumnHeader} = $ConfigObject->Get('Ticket::Frontend::OverviewSmall')->{ColumnHeader};
+
     # set pref for columns key
     $Self->{PrefKeyColumns} = 'UserFilterColumnsEnabled' . '-' . $Self->{Action};
 
@@ -244,15 +243,10 @@ sub ActionRow {
             $BulkFeature = 1;
         }
         else {
-            my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
             GROUP:
             for my $Group (@Groups) {
-                my $HasPermission = $GroupObject->PermissionCheck(
-                    UserID    => $Self->{UserID},
-                    GroupName => $Group,
-                    Type      => 'rw',
-                );
-                if ($HasPermission) {
+                next GROUP if !$LayoutObject->{"UserIsGroup[$Group]"};
+                if ( $LayoutObject->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
                     last GROUP;
                 }
@@ -285,9 +279,6 @@ sub ActionRow {
         );
     }
 
-    my %ColumnTranslations;
-    my $LanguageObject = $Kernel::OM->Get('Kernel::Language');
-
     # add translations for the allocation lists for regular columns
     my $Columns = $Self->{Config}->{DefaultColumns} || $ConfigObject->Get('DefaultOverviewColumns') || {};
     if ( $Columns && IsHashRefWithData($Columns) ) {
@@ -315,22 +306,21 @@ sub ActionRow {
                 $TranslatedWord = Translatable('Pending till');
             }
             elsif ( $Column eq 'CustomerCompanyName' ) {
-                $TranslatedWord = Translatable('Customer Name');
-            }
-            elsif ( $Column eq 'CustomerID' ) {
-                $TranslatedWord = Translatable('Customer ID');
-            }
-            elsif ( $Column eq 'CustomerName' ) {
-                $TranslatedWord = Translatable('Customer User Name');
+                $TranslatedWord = Translatable('Customer Company Name');
             }
             elsif ( $Column eq 'CustomerUserID' ) {
                 $TranslatedWord = Translatable('Customer User ID');
             }
 
-            # send data to JS
-            $LayoutObject->AddJSData(
-                Key   => 'Column' . $Column,
-                Value => $LanguageObject->Translate($TranslatedWord),
+            $LayoutObject->Block(
+                Name => 'ColumnTranslation',
+                Data => {
+                    ColumnName      => $Column,
+                    TranslateString => $TranslatedWord,
+                },
+            );
+            $LayoutObject->Block(
+                Name => 'ColumnTranslationSeparator',
             );
         }
     }
@@ -352,11 +342,19 @@ sub ActionRow {
 
             $Counter++;
 
-            # send data to JS
-            $LayoutObject->AddJSData(
-                Key   => 'ColumnDynamicField_' . $DynamicField->{Name},
-                Value => $LanguageObject->Translate( $DynamicField->{Label} ),
+            $LayoutObject->Block(
+                Name => 'ColumnTranslation',
+                Data => {
+                    ColumnName      => 'DynamicField_' . $DynamicField->{Name},
+                    TranslateString => $DynamicField->{Label},
+                },
             );
+
+            if ( $Counter < scalar @{$ColumnsDynamicField} ) {
+                $LayoutObject->Block(
+                    Name => 'ColumnTranslationSeparator',
+                );
+            }
         }
     }
 
@@ -385,11 +383,12 @@ sub Run {
         $Self->{AvailableFilterableColumns} = {};    # disable all column filters
     }
 
-    for my $Item (qw(TicketIDs PageShown StartHit)) {
-        if ( !$Param{$Item} ) {
+    # check needed stuff
+    for (qw(TicketIDs PageShown StartHit)) {
+        if ( !$Param{$_} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $Item!",
+                Message  => "Need $_!"
             );
             return;
         }
@@ -410,15 +409,10 @@ sub Run {
             $BulkFeature = 1;
         }
         else {
-            my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
             GROUP:
             for my $Group (@Groups) {
-                my $HasPermission = $GroupObject->PermissionCheck(
-                    UserID    => $Self->{UserID},
-                    GroupName => $Group,
-                    Type      => 'rw',
-                );
-                if ($HasPermission) {
+                next GROUP if !$LayoutObject->{"UserIsGroup[$Group]"};
+                if ( $LayoutObject->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
                     last GROUP;
                 }
@@ -428,84 +422,26 @@ sub Run {
 
     my $Counter = 0;
     my @ArticleBox;
-
-    my $TicketObject  = $Kernel::OM->Get('Kernel::System::Ticket');
-    my $ArticleObject = $Kernel::OM->Get('Kernel::System::Ticket::Article');
-
-    # Get extended ticket data if columns are used, save performance. See bug#14748.
-    my %ExtendedColumnsHash = (
-        FirstResponse          => 1,
-        FirstResponseInMin     => 1,
-        FirstResponseDiffInMin => 1,
-        SolutionInMin          => 1,
-        SolutionDiffInMin      => 1,
-        FirstLock              => 1,
-    );
-
-    my $Extended = 0;
-    if ( grep { $ExtendedColumnsHash{$_} } @{ $Self->{ColumnsEnabled} } ) {
-        $Extended = 1;
-    }
-
     for my $TicketID ( @{ $Param{TicketIDs} } ) {
         $Counter++;
         if ( $Counter >= $Param{StartHit} && $Counter < ( $Param{PageShown} + $Param{StartHit} ) ) {
 
-            # Get last customer article.
-            my @Articles = $ArticleObject->ArticleList(
-                TicketID   => $TicketID,
-                SenderType => 'customer',
-                OnlyLast   => 1,
-            );
+            # get ticket object
+            my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
-            # If the ticket has no customer article, get the last agent article.
-            if ( !@Articles ) {
-                @Articles = $ArticleObject->ArticleList(
-                    TicketID   => $TicketID,
-                    SenderType => 'agent',
-                    OnlyLast   => 1,
-                );
-            }
-
-            # Finally, if everything failed, get latest article.
-            if ( !@Articles ) {
-                @Articles = $ArticleObject->ArticleList(
-                    TicketID => $TicketID,
-                    OnlyLast => 1,
-                );
-            }
-
-            my %Article;
-            for my $Article (@Articles) {
-                %Article = $ArticleObject->BackendForArticle( %{$Article} )->ArticleGet(
-                    %{$Article},
-                    DynamicFields => 0,
-                );
-            }
-
-            # Get ticket data.
-            my %Ticket = $TicketObject->TicketGet(
+            # get last customer article
+            my %Article = $TicketObject->ArticleLastCustomerArticle(
                 TicketID      => $TicketID,
-                Extended      => $Extended,
                 DynamicFields => 0,
             );
 
-            %Article = ( %Article, %Ticket );
+            # get ticket data
+            my %Ticket = $TicketObject->TicketGet(
+                TicketID      => $TicketID,
+                DynamicFields => 0,
+            );
 
-            # Get channel specific fields.
-            if ( $Article{ArticleID} ) {
-                my %ArticleFields = $LayoutObject->ArticleFields(
-                    TicketID  => $TicketID,
-                    ArticleID => $Article{ArticleID},
-                );
-                FIELD:
-                for my $FieldKey (qw(Sender Subject)) {
-                    next FIELD if !defined $ArticleFields{$FieldKey}->{Value};
-                    $Article{$FieldKey} = $ArticleFields{$FieldKey}->{Realname} // $ArticleFields{$FieldKey}->{Value};
-                }
-            }
-
-            # Fallback for tickets without articles: get at least basic ticket data.
+            # Fallback for tickets without articles: get at least basic ticket data
             if ( !%Article ) {
                 %Article = %Ticket;
                 if ( !$Article{Title} ) {
@@ -519,6 +455,21 @@ sub Run {
             # show ticket create time in small view
             $Article{Created} = $Ticket{Created};
 
+            # prepare a "long" version of the subject to show in the title attribute. We don't take
+            # the whole string (which could be VERY long) to avoid polluting the DOM and having too
+            # much data to be transferred on large ticket lists
+            $Article{SubjectLong} = $TicketObject->TicketSubjectClean(
+                TicketNumber => $Article{TicketNumber},
+                Subject      => $Article{Subject} || '',
+                Size         => 500,
+            );
+
+            # prepare subject
+            $Article{Subject} = $TicketObject->TicketSubjectClean(
+                TicketNumber => $Article{TicketNumber},
+                Subject      => $Article{Subject} || '',
+            );
+
             # create human age
             $Article{Age} = $LayoutObject->CustomerAge(
                 Age   => $Article{Age},
@@ -648,12 +599,6 @@ sub Run {
         OriginalTicketIDs => $Param{OriginalTicketIDs},
     );
 
-    # send data to JS
-    $LayoutObject->AddJSData(
-        Key   => 'LinkPage',
-        Value => $Param{LinkPage},
-    );
-
     $LayoutObject->Block(
         Name => 'DocumentContent',
         Data => \%Param,
@@ -668,13 +613,12 @@ sub Run {
         Owner        => 1,
         Responsible  => 1,
         CustomerID   => 1,
+        Title        => 1,
     );
 
     # get dynamic field backend object
     my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
 
-    $Param{OrderBy} = $Param{OrderBy} || 'Up';
-
     my $TicketData = scalar @ArticleBox;
     if ($TicketData) {
 
@@ -699,26 +643,24 @@ sub Run {
                 Name => 'GeneralOverviewHeader',
             );
 
-            my $CSS     = '';
-            my $OrderBy = $Param{OrderBy};
+            my $CSS = '';
+            my $OrderBy;
             my $Link;
-            my $Title = $LayoutObject->{LanguageObject}->Translate($Item);
+            my $Title = $Item;
 
             if ( $Param{SortBy} && ( $Param{SortBy} eq $Item ) ) {
-                my $TitleDesc;
-
-                # Change order for sorting column.
-                $OrderBy = $OrderBy eq 'Up' ? 'Down' : 'Up';
-
-                if ( $OrderBy eq 'Down' ) {
+                if ( $Param{OrderBy} && ( $Param{OrderBy} eq 'Up' ) ) {
+                    $OrderBy = 'Down';
                     $CSS .= ' SortAscendingLarge';
-                    $TitleDesc = Translatable('sorted ascending');
                 }
                 else {
+                    $OrderBy = 'Up';
                     $CSS .= ' SortDescendingLarge';
-                    $TitleDesc = Translatable('sorted descending');
                 }
 
+                # set title description
+                my $TitleDesc
+                    = $OrderBy eq 'Down' ? Translatable('sorted descending') : Translatable('sorted ascending');
                 $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                 $Title .= ', ' . $TitleDesc;
             }
@@ -736,7 +678,7 @@ sub Run {
                     Name => 'OverviewNavBarPageFlagEmpty',
                     Data => {
                         Name => $Item,
-                    }
+                        }
                 );
             }
             else {
@@ -755,6 +697,7 @@ sub Run {
         }
 
         my $CSS = '';
+        my $OrderBy;
 
         # show special ticket columns, if needed
         COLUMN:
@@ -765,8 +708,7 @@ sub Run {
             );
 
             $CSS = $Column;
-            my $Title   = $LayoutObject->{LanguageObject}->Translate($Column);
-            my $OrderBy = $Param{OrderBy};
+            my $Title = $LayoutObject->{LanguageObject}->Translate($Column);
 
             # output overall block so TicketNumber as well as other columns can be ordered
             $LayoutObject->Block(
@@ -777,28 +719,37 @@ sub Run {
             if ( $SpecialColumns{$Column} ) {
 
                 if ( $Param{SortBy} && ( $Param{SortBy} eq $Column ) ) {
-                    my $TitleDesc;
-
-                    # Change order for sorting column.
-                    $OrderBy = $OrderBy eq 'Up' ? 'Down' : 'Up';
-
-                    if ( $OrderBy eq 'Down' ) {
+                    if ( $Param{OrderBy} && ( $Param{OrderBy} eq 'Up' ) ) {
+                        $OrderBy = 'Down';
                         $CSS .= ' SortAscendingLarge';
-                        $TitleDesc = Translatable('sorted ascending');
                     }
                     else {
+                        $OrderBy = 'Up';
                         $CSS .= ' SortDescendingLarge';
-                        $TitleDesc = Translatable('sorted descending');
                     }
 
+                    # add title description
+                    my $TitleDesc
+                        = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                     $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                     $Title .= ', ' . $TitleDesc;
                 }
 
                 # translate the column name to write it in the current language
                 my $TranslatedWord;
-                if ( $Column eq 'CustomerID' ) {
-                    $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Customer ID');
+
+                if ( $Column eq 'Title' ) {
+
+                    $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('From') . ' / ';
+
+                    if ( $Self->{SmallViewColumnHeader} eq 'LastCustomerSubject' ) {
+                        $TranslatedWord
+                            .= $LayoutObject->{LanguageObject}->Translate('Subject');
+                    }
+                    elsif ( $Self->{SmallViewColumnHeader} eq 'TicketTitle' ) {
+                        $TranslatedWord
+                            .= $LayoutObject->{LanguageObject}->Translate('Title');
+                    }
                 }
                 else {
                     $TranslatedWord = $LayoutObject->{LanguageObject}->Translate($Column);
@@ -842,7 +793,7 @@ sub Run {
                     )
                 {
                     my $Css;
-                    if ( $Column eq 'CustomerID' || $Column eq 'Owner' || $Column eq 'Responsible' ) {
+                    if ( $Column eq 'CustomerID' || $Column eq 'Owner' ) {
                         $Css .= ' Hidden';
                     }
 
@@ -874,40 +825,28 @@ sub Run {
                         $LayoutObject->Block(
                             Name =>
                                 'ContentLargeTicketGenericHeaderColumnFilterLinkCustomerIDSearch',
-                            Data => {},
-                        );
-
-                        # send data to JS
-                        $LayoutObject->AddJSData(
-                            Key   => 'CustomerIDAutocomplete',
-                            Value => {
-                                'QueryDelay'          => 100,
-                                'MaxResultsDisplayed' => 20,
-                                'MinQueryLength'      => 2,
+                            Data => {
+                                minQueryLength      => 2,
+                                queryDelay          => 100,
+                                maxResultsDisplayed => 20,
                             },
                         );
                     }
-                    elsif ( $Column eq 'Owner' || $Column eq 'Responsible' ) {
+                    elsif ( $Column eq 'Owner' ) {
 
                         $LayoutObject->Block(
                             Name => 'ContentLargeTicketGenericHeaderColumnFilterLinkUserSearch',
-                            Data => {},
-                        );
-
-                        # send data to JS
-                        $LayoutObject->AddJSData(
-                            Key   => 'UserAutocomplete',
-                            Value => {
-                                'QueryDelay'          => 100,
-                                'MaxResultsDisplayed' => 20,
-                                'MinQueryLength'      => 2,
+                            Data => {
+                                minQueryLength      => 2,
+                                queryDelay          => 100,
+                                maxResultsDisplayed => 20,
                             },
                         );
                     }
 
                 }
 
-                # verify if column is filterable
+                # verify if column is filterable and sortable
                 elsif ( $Self->{ValidFilterableColumns}->{$Column} ) {
 
                     # variable to save the filter's HTML code
@@ -964,20 +903,18 @@ sub Run {
             elsif ( $Column !~ m{\A DynamicField_}xms ) {
 
                 if ( $Param{SortBy} && ( $Param{SortBy} eq $Column ) ) {
-                    my $TitleDesc;
-
-                    # Change order for sorting column.
-                    $OrderBy = $OrderBy eq 'Up' ? 'Down' : 'Up';
-
-                    if ( $OrderBy eq 'Down' ) {
+                    if ( $Param{OrderBy} && ( $Param{OrderBy} eq 'Up' ) ) {
+                        $OrderBy = 'Down';
                         $CSS .= ' SortAscendingLarge';
-                        $TitleDesc = Translatable('sorted ascending');
                     }
                     else {
+                        $OrderBy = 'Up';
                         $CSS .= ' SortDescendingLarge';
-                        $TitleDesc = Translatable('sorted descending');
                     }
 
+                    # add title description
+                    my $TitleDesc
+                        = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                     $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                     $Title .= ', ' . $TitleDesc;
                 }
@@ -1000,10 +937,7 @@ sub Run {
                     $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Pending till');
                 }
                 elsif ( $Column eq 'CustomerCompanyName' ) {
-                    $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Customer Name');
-                }
-                elsif ( $Column eq 'CustomerName' ) {
-                    $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Customer User Name');
+                    $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Customer Company Name');
                 }
                 elsif ( $Column eq 'CustomerUserID' ) {
                     $TranslatedWord = $LayoutObject->{LanguageObject}->Translate('Customer User ID');
@@ -1037,6 +971,10 @@ sub Run {
                     && $Self->{ValidSortableColumns}->{$Column}
                     )
                 {
+                    my $Css;
+                    if ( $Column eq 'Responsible' ) {
+                        $Css .= ' Hidden';
+                    }
 
                     # variable to save the filter's HTML code
                     my $ColumnFilterHTML = $Self->_InitialColumnFilter(
@@ -1044,6 +982,7 @@ sub Run {
                         Label         => $Column,
                         ColumnValues  => $ColumnValues->{$Column},
                         SelectedValue => $Param{GetColumnFilter}->{$Column} || '',
+                        Css           => $Css,
                     );
 
                     $LayoutObject->Block(
@@ -1059,6 +998,19 @@ sub Run {
                             FilterTitle          => $FilterTitle,
                         },
                     );
+
+                    if ( $Column eq 'Responsible' ) {
+
+                        $LayoutObject->Block(
+                            Name => 'ContentLargeTicketGenericHeaderColumnFilterLinkUserSearch',
+                            Data => {
+                                minQueryLength      => 2,
+                                queryDelay          => 100,
+                                maxResultsDisplayed => 20,
+                            },
+                        );
+                    }
+
                 }
 
                 # verify if column is just filterable
@@ -1095,16 +1047,10 @@ sub Run {
                         $LayoutObject->Block(
                             Name =>
                                 'ContentLargeTicketGenericHeaderColumnFilterLinkCustomerUserSearch',
-                            Data => {},
-                        );
-
-                        # send data to JS
-                        $LayoutObject->AddJSData(
-                            Key   => 'CustomerUserAutocomplete',
-                            Value => {
-                                'QueryDelay'          => 100,
-                                'MaxResultsDisplayed' => 20,
-                                'MinQueryLength'      => 2,
+                            Data => {
+                                minQueryLength      => 2,
+                                queryDelay          => 100,
+                                maxResultsDisplayed => 20,
                             },
                         );
                     }
@@ -1166,25 +1112,24 @@ sub Run {
 
                 if ($IsSortable) {
                     my $CSS = 'DynamicField_' . $DynamicFieldConfig->{Name};
+                    my $OrderBy;
                     if (
                         $Param{SortBy}
                         && ( $Param{SortBy} eq ( 'DynamicField_' . $DynamicFieldConfig->{Name} ) )
                         )
                     {
-                        my $TitleDesc;
-
-                        # Change order for sorting column.
-                        $OrderBy = $OrderBy eq 'Up' ? 'Down' : 'Up';
-
-                        if ( $OrderBy eq 'Down' ) {
+                        if ( $Param{OrderBy} && ( $Param{OrderBy} eq 'Up' ) ) {
+                            $OrderBy = 'Down';
                             $CSS .= ' SortAscendingLarge';
-                            $TitleDesc = Translatable('sorted ascending');
                         }
                         else {
+                            $OrderBy = 'Up';
                             $CSS .= ' SortDescendingLarge';
-                            $TitleDesc = Translatable('sorted descending');
                         }
 
+                        # add title description
+                        my $TitleDesc
+                            = $OrderBy eq 'Down' ? Translatable('sorted ascending') : Translatable('sorted descending');
                         $TitleDesc = $LayoutObject->{LanguageObject}->Translate($TitleDesc);
                         $Title .= ', ' . $TitleDesc;
                     }
@@ -1225,6 +1170,7 @@ sub Run {
                                 Label            => $Label,
                                 DynamicFieldName => $DynamicFieldConfig->{Name},
                                 ColumnFilterStrg => $ColumnFilterHTML,
+                                OrderBy          => $OrderBy,
                                 Title            => $Title,
                                 FilterTitle      => $FilterTitle,
                             },
@@ -1273,6 +1219,7 @@ sub Run {
                                 Label            => $Label,
                                 DynamicFieldName => $DynamicFieldConfig->{Name},
                                 ColumnFilterStrg => $ColumnFilterHTML,
+                                OrderBy          => $OrderBy,
                                 Title            => $Title,
                             },
                         );
@@ -1394,8 +1341,6 @@ sub Run {
         $LayoutObject->Block( Name => 'NoTicketFound' );
     }
 
-    my %ActionRowTickets;
-
     for my $ArticleRef (@ArticleBox) {
 
         # get last customer article
@@ -1403,15 +1348,13 @@ sub Run {
 
         # escalation human times
         if ( $Article{EscalationTime} ) {
-            $Article{EscalationTimeHuman} = $LayoutObject->CustomerAge(
-                Age                => $Article{EscalationTime},
-                TimeShowAlwaysLong => 1,
-                Space              => ' ',
+            $Article{EscalationTimeHuman} = $LayoutObject->CustomerAgeInHours(
+                Age   => $Article{EscalationTime},
+                Space => ' ',
             );
-            $Article{EscalationTimeWorkingTime} = $LayoutObject->CustomerAge(
-                Age                => $Article{EscalationTimeWorkingTime},
-                TimeShowAlwaysLong => 1,
-                Space              => ' ',
+            $Article{EscalationTimeWorkingTime} = $LayoutObject->CustomerAgeInHours(
+                Age   => $Article{EscalationTimeWorkingTime},
+                Space => ' ',
             );
         }
 
@@ -1506,24 +1449,28 @@ sub Run {
                 );
 
                 if ( $SpecialColumns{$TicketColumn} ) {
-                    $LayoutObject->Block(
-                        Name => 'Record' . $TicketColumn,
-                        Data => { %Article, %UserInfo },
-                    );
+                    if ( $TicketColumn eq 'Title' ) {
 
-                    next TICKETCOLUMN;
-                }
-
-                if ( $TicketColumn eq 'CreatedBy' ) {
-
-                    my %TicketCreatedByInfo = $UserObject->GetUserData(
-                        UserID => $Article{CreateBy},
-                    );
-
-                    $LayoutObject->Block(
-                        Name => 'RecordTicketCreatedBy',
-                        Data => \%TicketCreatedByInfo,
-                    );
+                        # check if last customer subject or ticket title should be shown
+                        if ( $Self->{SmallViewColumnHeader} eq 'LastCustomerSubject' ) {
+                            $LayoutObject->Block(
+                                Name => 'RecordLastCustomerSubject',
+                                Data => { %Article, %UserInfo },
+                            );
+                        }
+                        elsif ( $Self->{SmallViewColumnHeader} eq 'TicketTitle' ) {
+                            $LayoutObject->Block(
+                                Name => 'RecordTicketTitle',
+                                Data => { %Article, %UserInfo },
+                            );
+                        }
+                    }
+                    else {
+                        $LayoutObject->Block(
+                            Name => 'Record' . $TicketColumn,
+                            Data => { %Article, %UserInfo },
+                        );
+                    }
                     next TICKETCOLUMN;
                 }
 
@@ -1533,15 +1480,13 @@ sub Run {
                     $EscalationData{EscalationTime}            = $Article{EscalationTime};
                     $EscalationData{EscalationDestinationDate} = $Article{EscalationDestinationDate};
 
-                    $EscalationData{EscalationTimeHuman} = $LayoutObject->CustomerAge(
-                        Age                => $EscalationData{EscalationTime},
-                        TimeShowAlwaysLong => 1,
-                        Space              => ' ',
-                    ) || '-';
-                    $EscalationData{EscalationTimeWorkingTime} = $LayoutObject->CustomerAge(
-                        Age                => $EscalationData{EscalationTimeWorkingTime},
-                        TimeShowAlwaysLong => 1,
-                        Space              => ' ',
+                    $EscalationData{EscalationTimeHuman} = $LayoutObject->CustomerAgeInHours(
+                        Age   => $EscalationData{EscalationTime},
+                        Space => ' ',
+                    );
+                    $EscalationData{EscalationTimeWorkingTime} = $LayoutObject->CustomerAgeInHours(
+                        Age   => $EscalationData{EscalationTimeWorkingTime},
+                        Space => ' ',
                     );
                     if (
                         defined $Article{EscalationTime}
@@ -1561,10 +1506,9 @@ sub Run {
                 my $CSSClass  = '';
                 if ( $TicketColumn eq 'EscalationSolutionTime' ) {
                     $BlockType = 'Escalation';
-                    $DataValue = $LayoutObject->CustomerAge(
-                        Age                => $Article{SolutionTime} || 0,
-                        TimeShowAlwaysLong => 1,
-                        Space              => ' ',
+                    $DataValue = $LayoutObject->CustomerAgeInHours(
+                        Age => $Article{SolutionTime} || 0,
+                        Space => ' ',
                     );
                     if ( defined $Article{SolutionTime} && $Article{SolutionTime} < 60 * 60 * 1 ) {
                         $CSSClass = 'Warning';
@@ -1572,10 +1516,9 @@ sub Run {
                 }
                 elsif ( $TicketColumn eq 'EscalationResponseTime' ) {
                     $BlockType = 'Escalation';
-                    $DataValue = $LayoutObject->CustomerAge(
-                        Age                => $Article{FirstResponseTime} || 0,
-                        TimeShowAlwaysLong => 1,
-                        Space              => ' ',
+                    $DataValue = $LayoutObject->CustomerAgeInHours(
+                        Age => $Article{FirstResponseTime} || 0,
+                        Space => ' ',
                     );
                     if (
                         defined $Article{FirstResponseTime}
@@ -1587,10 +1530,9 @@ sub Run {
                 }
                 elsif ( $TicketColumn eq 'EscalationUpdateTime' ) {
                     $BlockType = 'Escalation';
-                    $DataValue = $LayoutObject->CustomerAge(
-                        Age                => $Article{UpdateTime} || 0,
-                        TimeShowAlwaysLong => 1,
-                        Space              => ' ',
+                    $DataValue = $LayoutObject->CustomerAgeInHours(
+                        Age => $Article{UpdateTime} || 0,
+                        Space => ' ',
                     );
                     if ( defined $Article{UpdateTime} && $Article{UpdateTime} < 60 * 60 * 1 ) {
                         $CSSClass = 'Warning';
@@ -1619,33 +1561,16 @@ sub Run {
                     $BlockType = 'Time';
                     $DataValue = $Article{$TicketColumn} || $UserInfo{$TicketColumn};
                 }
-                elsif ( $TicketColumn eq 'Responsible' ) {
-
-                    my %ResponsibleInfo = $UserObject->GetUserData(
-                        UserID => $Article{ResponsibleID},
-                    );
-
-                    $DataValue = $ResponsibleInfo{'UserFullname'};
-                }
                 else {
                     $DataValue = $Article{$TicketColumn}
                         || $UserInfo{$TicketColumn}
                         || $CustomerInfo{$TicketColumn};
-
-                    # If value is in date format, change block type to 'Time' so it can be localized. See bug#14542.
-                    if (
-                        defined $DataValue
-                        && $DataValue =~ /^\d\d\d\d-(\d|\d\d)-(\d|\d\d)\s(\d|\d\d):(\d|\d\d):(\d|\d\d)/
-                        )
-                    {
-                        $BlockType = 'Time';
-                    }
                 }
 
                 $LayoutObject->Block(
                     Name => "RecordTicketColumn$BlockType",
                     Data => {
-                        GenericValue => $DataValue || '-',
+                        GenericValue => $DataValue || '',
                         Class        => $CSSClass  || '',
                     },
                 );
@@ -1746,24 +1671,20 @@ sub Run {
         # add action items as js
         if ( $Article{ActionItems} ) {
 
-            # replace TT directives from string with values
-            for my $ActionItem ( @{ $Article{ActionItems} } ) {
-                $ActionItem->{Link} = $LayoutObject->Output(
-                    Template => $ActionItem->{Link},
-                    Data     => {
-                        TicketID => $Article{TicketID},
-                    },
-                );
-            }
-
-            $ActionRowTickets{ $Article{TicketID} } = $LayoutObject->JSONEncode( Data => $Article{ActionItems} );
+            $LayoutObject->Block(
+                Name => 'DocumentReadyActionRowAdd',
+                Data => {
+                    TicketID => $Article{TicketID},
+                    Data     => $Article{ActionItems},
+                },
+            );
         }
     }
 
-    # send data to JS
-    $LayoutObject->AddJSData(
-        Key   => 'ActionRowTickets',
-        Value => \%ActionRowTickets,
+    # init for table control
+    $LayoutObject->Block(
+        Name => 'DocumentReadyStart',
+        Data => \%Param,
     );
 
     # set column filter form, to correctly fill the column filters is necessary to pass each
@@ -1776,12 +1697,6 @@ sub Run {
             Name => 'DocumentColumnFilterForm',
             Data => {},
         );
-
-        # Add UseSubQueues param if available.
-        if ( $Param{UseSubQueues} ) {
-            $Param{ColumnFilterForm}->{UseSubQueues} = $Param{UseSubQueues};
-        }
-
         for my $Element ( sort keys %{ $Param{ColumnFilterForm} } ) {
             $LayoutObject->Block(
                 Name => 'DocumentColumnFilterFormElement',
@@ -1933,7 +1848,7 @@ sub FilterContent {
     if ( $HeaderColumn eq 'CustomerUserID' ) {
         $SelectedColumn = 'CustomerUserLogin';
     }
-    elsif ( $HeaderColumn eq 'CustomerID' ) {
+    if ( $HeaderColumn eq 'CustomerID' ) {
         $SelectedColumn = 'CustomerID';
     }
     elsif ( $HeaderColumn !~ m{ \A DynamicField_ }xms ) {
@@ -1980,21 +1895,23 @@ sub FilterContent {
     return $ColumnFilterJSON;
 }
 
-# =head2 _ColumnFilterJSON()
+=over
 
-#     creates a JSON select filter for column header
+=item _ColumnFilterJSON()
 
-#     my $ColumnFilterJSON = $TicketOverviewSmallObject->_ColumnFilterJSON(
-#         ColumnName => 'Queue',
-#         Label      => 'Queue',
-#         ColumnValues => {
-#             1 => 'PostMaster',
-#             2 => 'Junk',
-#         },
-#         SelectedValue '1',
-#     );
+    creates a JSON select filter for column header
 
-# =cut
+    my $ColumnFilterJSON = $TicketOverviewSmallObject->_ColumnFilterJSON(
+        ColumnName => 'Queue',
+        Label      => 'Queue',
+        ColumnValues => {
+            1 => 'PostMaster',
+            2 => 'Junk',
+        },
+        SelectedValue '1',
+    );
+
+=cut
 
 sub _ColumnFilterJSON {
     my ( $Self, %Param ) = @_;
@@ -2031,16 +1948,11 @@ sub _ColumnFilterJSON {
 
         my %Values = %{ $Param{ColumnValues} };
 
-        # Keys must be link encoded for dynamic fields because they are added to URL during filtering
-        # and can contain characters like '&', ';', etc.
-        # See bug#14497 - https://bugs.otrs.org/show_bug.cgi?id=14497.
-        my $Encoding = ( $Param{ColumnName} =~ m/^DynamicField_/ ) ? 1 : 0;
-
-        # Set possible values.
+        # set possible values
         for my $ValueKey ( sort { lc $Values{$a} cmp lc $Values{$b} } keys %Values ) {
             push @{$Data}, {
-                Key   => $Encoding ? $LayoutObject->LinkEncode($ValueKey) : $ValueKey,
-                Value => $Values{$ValueKey},
+                Key   => $ValueKey,
+                Value => $Values{$ValueKey}
             };
         }
     }
@@ -2087,9 +1999,7 @@ sub _DefaultColumnSort {
         EscalationSolutionTime => 114,
         EscalationResponseTime => 115,
         EscalationUpdateTime   => 116,
-        Sender                 => 120,
-        Title                  => 122,
-        Subject                => 124,
+        Title                  => 120,
         State                  => 130,
         Lock                   => 140,
         Queue                  => 150,
@@ -2125,3 +2035,5 @@ sub _DefaultColumnSort {
 }
 
 1;
+
+=back
