@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -7,12 +7,13 @@
 # --
 
 package Kernel::System::DB;
-## nofilter(TidyAll::Plugin::OTRS::Perl::PODSpelling)
+## nofilter(TidyAll::Plugin::OTRS::Perl::Pod::FunctionPod)
 
 use strict;
 use warnings;
 
 use DBI;
+use List::Util();
 
 use Kernel::System::VariableCheck qw(:all);
 
@@ -58,7 +59,6 @@ Usually you do not use it directly, instead use:
                 LongTruncOk => 1,
                 LongReadLen => 100*1024,
             },
-            AutoConnectNo => 0, # 0|1 disable auto-connect to database in constructor
         },
     );
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
@@ -83,6 +83,8 @@ sub new {
     $Self->{USER} = $Param{DatabaseUser} || $ConfigObject->Get('DatabaseUser');
     $Self->{PW}   = $Param{DatabasePw}   || $ConfigObject->Get('DatabasePw');
 
+    $Self->{IsSlaveDB} = $Param{IsSlaveDB};
+
     $Self->{SlowLog} = $Param{'Database::SlowLog'}
         || $ConfigObject->Get('Database::SlowLog');
 
@@ -152,11 +154,6 @@ sub new {
         }
     }
 
-    # do database connect
-    if ( !$Param{AutoConnectNo} ) {
-        return if !$Self->Connect();
-    }
-
     return $Self;
 }
 
@@ -171,6 +168,26 @@ to connect to a database
 sub Connect {
     my $Self = shift;
 
+    # check database handle
+    if ( $Self->{dbh} ) {
+
+        my $PingTimeout = 10;        # Only ping every 10 seconds (see bug#12383).
+        my $CurrentTime = time();    ## no critic
+
+        if ( $CurrentTime - ( $Self->{LastPingTime} // 0 ) < $PingTimeout ) {
+            return $Self->{dbh};
+        }
+
+        # Ping to see if the connection is still alive.
+        if ( $Self->{dbh}->ping() ) {
+            $Self->{LastPingTime} = $CurrentTime;
+            return $Self->{dbh};
+        }
+
+        # Ping failed: cause a reconnect.
+        delete $Self->{dbh};
+    }
+
     # debug
     if ( $Self->{Debug} > 2 ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -237,6 +254,7 @@ sub Disconnect {
     # do disconnect
     if ( $Self->{dbh} ) {
         $Self->{dbh}->disconnect();
+        delete $Self->{dbh};
     }
 
     if ( $Self->{SlaveDBObject} ) {
@@ -383,7 +401,7 @@ sub Do {
     if ( !$Param{SQL} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need SQL!'
+            Message  => 'Need SQL!',
         );
         return;
     }
@@ -437,6 +455,8 @@ sub Do {
         );
     }
 
+    return if !$Self->Connect();
+
     # send sql to database
     if ( !$Self->{dbh}->do( $Param{SQL}, undef, @Array ) ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -456,29 +476,56 @@ sub _InitSlaveDB {
     # Run only once!
     return $Self->{SlaveDBObject} if $Self->{_InitSlaveDB}++;
 
-    my $ConfigObject  = $Kernel::OM->Get('Kernel::Config');
-    my $MasterDSN     = $ConfigObject->Get('DatabaseDSN');
-    my $SlaveDSN      = $ConfigObject->Get('Core::MirrorDB::DSN');
-    my $SlaveUser     = $ConfigObject->Get('Core::MirrorDB::User');
-    my $SlavePassword = $ConfigObject->Get('Core::MirrorDB::Password');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $MasterDSN    = $ConfigObject->Get('DatabaseDSN');
 
-    # If a slave is configured and it is not already used in the current object
-    #   and we are actually in the master connection object: then create a slave.
-    if (
-        $SlaveDSN
-        && $SlaveUser
-        && $SlavePassword
-        && $SlaveDSN ne $Self->{DSN}
-        && $MasterDSN eq $Self->{DSN}
-        )
-    {
-        $Self->{SlaveDBObject} = Kernel::System::DB->new(
-            DatabaseDSN  => $SlaveDSN,
-            DatabaseUser => $SlaveUser,
-            DatabasePw   => $SlavePassword,
-        );
+    # Don't create slave if we are already in a slave, or if we are not in the master,
+    #   such as in an external customer user database handle.
+    if ( $Self->{IsSlaveDB} || $MasterDSN ne $Self->{DSN} ) {
+        return $Self->{SlaveDBObject};
     }
-    return $Self->{SlaveDBObject};
+
+    my %SlaveConfiguration = (
+        %{ $ConfigObject->Get('Core::MirrorDB::AdditionalMirrors') // {} },
+        0 => {
+            DSN      => $ConfigObject->Get('Core::MirrorDB::DSN'),
+            User     => $ConfigObject->Get('Core::MirrorDB::User'),
+            Password => $ConfigObject->Get('Core::MirrorDB::Password'),
+            }
+    );
+
+    return $Self->{SlaveDBObject} if !%SlaveConfiguration;
+
+    SLAVE_INDEX:
+    for my $SlaveIndex ( List::Util::shuffle( keys %SlaveConfiguration ) ) {
+
+        my %CurrentSlave = %{ $SlaveConfiguration{$SlaveIndex} // {} };
+        next SLAVE_INDEX if !%CurrentSlave;
+
+        # If a slave is configured and it is not already used in the current object
+        #   and we are actually in the master connection object: then create a slave.
+        if (
+            $CurrentSlave{DSN}
+            && $CurrentSlave{User}
+            && $CurrentSlave{Password}
+            )
+        {
+            my $SlaveDBObject = Kernel::System::DB->new(
+                DatabaseDSN  => $CurrentSlave{DSN},
+                DatabaseUser => $CurrentSlave{User},
+                DatabasePw   => $CurrentSlave{Password},
+                IsSlaveDB    => 1,
+            );
+
+            if ( $SlaveDBObject->Connect() ) {
+                $Self->{SlaveDBObject} = $SlaveDBObject;
+                return $Self->{SlaveDBObject};
+            }
+        }
+    }
+
+    # no connect was possible.
+    return;
 }
 
 =item Prepare()
@@ -529,7 +576,7 @@ sub Prepare {
     if ( !$Param{SQL} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need SQL!'
+            Message  => 'Need SQL!',
         );
         return;
     }
@@ -539,6 +586,7 @@ sub Prepare {
     # Route SELECT statements to the DB slave if requested and a slave is configured.
     if (
         $UseSlaveDB
+        && !$Self->{IsSlaveDB}
         && $Self->_InitSlaveDB()    # this is very cheap after the first call (cached)
         && $SQL =~ m{\A\s*SELECT}xms
         )
@@ -615,6 +663,8 @@ sub Prepare {
         }
     }
 
+    return if !$Self->Connect();
+
     # do
     if ( !( $Self->{Cursor} = $Self->{dbh}->prepare($SQL) ) ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -645,6 +695,7 @@ sub Prepare {
             );
         }
     }
+
     return 1;
 }
 
@@ -666,7 +717,7 @@ to process the results of a SELECT statement
 sub FetchrowArray {
     my $Self = shift;
 
-    if ( $UseSlaveDB && $Self->{_PreparedOnSlaveDB} && $Self->_InitSlaveDB() ) {
+    if ( $Self->{_PreparedOnSlaveDB} ) {
         return $Self->{SlaveDBObject}->FetchrowArray();
     }
 
@@ -783,19 +834,20 @@ sub SelectAll {
 =item GetDatabaseFunction()
 
 to get database functions like
-    o Limit
-    o DirectBlob
-    o QuoteSingle
-    o QuoteBack
-    o QuoteSemicolon
-    o NoLikeInLargeText
-    o CurrentTimestamp
-    o Encode
-    o Comment
-    o ShellCommit
-    o ShellConnect
-    o Connect
-    o LikeEscapeString
+
+    - Limit
+    - DirectBlob
+    - QuoteSingle
+    - QuoteBack
+    - QuoteSemicolon
+    - NoLikeInLargeText
+    - CurrentTimestamp
+    - Encode
+    - Comment
+    - ShellCommit
+    - ShellConnect
+    - Connect
+    - LikeEscapeString
 
     my $What = $DBObject->GetDatabaseFunction('DirectBlob');
 
@@ -1088,8 +1140,8 @@ generate SQL condition query based on a search expression
     )
 
 Note that the comparisons are usually performed case insensitively.
-Only VARCHAR colums with a size less or equal 3998 are supported,
-as for locator objects the functioning of SQL function LOWER() can't
+Only C<VARCHAR> columns with a size less or equal 3998 are supported,
+as for locator objects the functioning of SQL function C<LOWER()> can't
 be guaranteed.
 
 =cut
@@ -1546,6 +1598,38 @@ sub QueryStringEscape {
     return $Param{QueryString};
 }
 
+=item Ping()
+
+checks if the database is reachable
+
+    my $Success = $DBObject->Ping(
+        AutoConnect => 0,  # default 1
+    );
+
+=cut
+
+sub Ping {
+    my ( $Self, %Param ) = @_;
+
+    # debug
+    if ( $Self->{Debug} > 2 ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Caller   => 1,
+            Priority => 'debug',
+            Message  => 'DB.pm->Ping',
+        );
+    }
+
+    if ( !defined $Param{AutoConnect} || $Param{AutoConnect} ) {
+        return if !$Self->Connect();
+    }
+    else {
+        return if !$Self->{dbh};
+    }
+
+    return $Self->{dbh}->ping();
+}
+
 =begin Internal:
 
 =cut
