@@ -214,22 +214,6 @@ sub GetObjectAttributes {
             Element          => 'Title',
             Block            => 'InputField',
         },
-        {
-            Name             => Translatable('CustomerUserLogin (complex search)'),
-            UseAsXvalue      => 0,
-            UseAsValueSeries => 0,
-            UseAsRestriction => 1,
-            Element          => 'CustomerUserLogin',
-            Block            => 'InputField',
-        },
-        {
-            Name             => Translatable('CustomerUserLogin (exact match)'),
-            UseAsXvalue      => 0,
-            UseAsValueSeries => 0,
-            UseAsRestriction => 1,
-            Element          => 'CustomerUserLoginRaw',
-            Block            => 'InputField',
-        },
         {
             Name             => Translatable('From'),
             UseAsXvalue      => 0,
@@ -447,8 +431,7 @@ sub GetObjectAttributes {
 
     if ( $ConfigObject->Get('Stats::CustomerIDAsMultiSelect') ) {
 
-        # Get CustomerID
-        # (This way also can be the solution for the CustomerUserID)
+        # Get all CustomerIDs which are related to a ticket.
         $DBObject->Prepare(
             SQL => "SELECT DISTINCT customer_id FROM ticket",
         );
@@ -497,6 +480,57 @@ sub GetObjectAttributes {
         push @ObjectAttributes, @CustomerIDAttributes;
     }
 
+    if ( $ConfigObject->Get('Stats::CustomerUserLoginsAsMultiSelect') ) {
+
+        # Get all CustomerUserLogins which are related to a tiket.
+        $DBObject->Prepare(
+            SQL => "SELECT DISTINCT customer_user_id FROM ticket",
+        );
+
+        # fetch the result
+        my %CustomerUserIDs;
+        while ( my @Row = $DBObject->FetchrowArray() ) {
+            if ( $Row[0] ) {
+                $CustomerUserIDs{ $Row[0] } = $Row[0];
+            }
+        }
+
+        my %ObjectAttribute = (
+            Name             => Translatable('CustomerUserLogin'),
+            UseAsXvalue      => 1,
+            UseAsValueSeries => 1,
+            UseAsRestriction => 1,
+            Element          => 'CustomerUserLoginRaw',
+            Block            => 'MultiSelectField',
+            Values           => \%CustomerUserIDs,
+        );
+
+        push @ObjectAttributes, \%ObjectAttribute;
+    }
+    else {
+
+        my @CustomerIDAttributes = (
+            {
+                Name             => Translatable('CustomerUserLogin (complex search)'),
+                UseAsXvalue      => 0,
+                UseAsValueSeries => 0,
+                UseAsRestriction => 1,
+                Element          => 'CustomerUserLogin',
+                Block            => 'InputField',
+            },
+            {
+                Name             => Translatable('CustomerUserLogin (exact match)'),
+                UseAsXvalue      => 0,
+                UseAsValueSeries => 0,
+                UseAsRestriction => 1,
+                Element          => 'CustomerUserLoginRaw',
+                Block            => 'InputField',
+            },
+        );
+
+        push @ObjectAttributes, @CustomerIDAttributes;
+    }
+
     # get dynamic field backend object
     my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
 
@@ -1070,6 +1104,8 @@ sub _ReportingValues {
     my %SolutionAllOver;
     my %Solution;
     my %SolutionWorkingTime;
+
+    # Response is only the first response and nothing with the update time.
     my %Response;
     my %ResponseWorkingTime;
 
@@ -1300,15 +1336,15 @@ sub _KindsOfReporting {
             Translatable('Solution Min Working Time (affected by escalation configuration)'),
         SolutionMaxWorkingTime =>
             Translatable('Solution Max Working Time (affected by escalation configuration)'),
-        ResponseAverage => Translatable('Response Average (affected by escalation configuration)'),
-        ResponseMinTime => Translatable('Response Min Time (affected by escalation configuration)'),
-        ResponseMaxTime => Translatable('Response Max Time (affected by escalation configuration)'),
+        ResponseAverage => Translatable('First Response Average (affected by escalation configuration)'),
+        ResponseMinTime => Translatable('First Response Min Time (affected by escalation configuration)'),
+        ResponseMaxTime => Translatable('First Response Max Time (affected by escalation configuration)'),
         ResponseWorkingTimeAverage =>
-            Translatable('Response Working Time Average (affected by escalation configuration)'),
+            Translatable('First Response Working Time Average (affected by escalation configuration)'),
         ResponseMinWorkingTime =>
-            Translatable('Response Min Working Time (affected by escalation configuration)'),
+            Translatable('First Response Min Working Time (affected by escalation configuration)'),
         ResponseMaxWorkingTime =>
-            Translatable('Response Max Working Time (affected by escalation configuration)'),
+            Translatable('First Response Max Working Time (affected by escalation configuration)'),
         NumberOfTickets => Translatable('Number of Tickets (affected by escalation configuration)'),
     );
     return \%KindsOfReporting;
