@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Ticket::ArticleStorageFS;
@@ -359,22 +359,20 @@ sub ArticleWriteAttachment {
         ArticleID => $Param{ArticleID},
         UserID    => $Param{UserID},
     );
-    if ( !$Param{Force} ) {
 
-        # Normalize filenames to find file names which are identical but in a different unicode form.
-        #   This is needed because Mac OS (HFS+) converts all filenames to NFD internally.
-        #   Without this, the same file might be overwritten because the strings are not equal.
-        for ( sort keys %Index ) {
-            $UsedFile{ Unicode::Normalize::NFC( $Index{$_}->{Filename} ) } = 1;
-        }
-        for ( my $i = 1; $i <= 50; $i++ ) {
-            if ( exists $UsedFile{ Unicode::Normalize::NFC($NewFileName) } ) {
-                if ( $Param{Filename} =~ /^(.*)\.(.+?)$/ ) {
-                    $NewFileName = "$1-$i.$2";
-                }
-                else {
-                    $NewFileName = "$Param{Filename}-$i";
-                }
+    # Normalize filenames to find file names which are identical but in a different unicode form.
+    #   This is needed because Mac OS (HFS+) converts all filenames to NFD internally.
+    #   Without this, the same file might be overwritten because the strings are not equal.
+    for ( sort keys %Index ) {
+        $UsedFile{ Unicode::Normalize::NFC( $Index{$_}->{Filename} ) } = 1;
+    }
+    for ( my $i = 1; $i <= 50; $i++ ) {
+        if ( exists $UsedFile{ Unicode::Normalize::NFC($NewFileName) } ) {
+            if ( $Param{Filename} =~ /^(.*)\.(.+?)$/ ) {
+                $NewFileName = "$1-$i.$2";
+            }
+            else {
+                $NewFileName = "$Param{Filename}-$i";
             }
         }
     }
@@ -698,7 +696,7 @@ sub ArticleAttachmentIndexRaw {
 
             # converted article body should be inline
             elsif ( $Filename =~ m{file-[12]} ) {
-                $Disposition = 'inline';
+                $Disposition = 'inline'
             }
 
             # all others including attachments with content id that are not images
@@ -961,7 +959,7 @@ sub ArticleAttachment {
 
                     # converted article body should be inline
                     elsif ( $Filename =~ m{file-[12]} ) {
-                        $Data{Disposition} = 'inline';
+                        $Data{Disposition} = 'inline'
                     }
 
                     # all others including attachments with content id that are not images
@@ -1075,7 +1073,7 @@ sub ArticleAttachment {
 
         # converted article body should be inline
         elsif ( $Data{Filename} =~ m{file-[12]} ) {
-            $Data{Disposition} = 'inline';
+            $Data{Disposition} = 'inline'
         }
 
         # all others including attachments with content id that are not images
