@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::User;
@@ -22,6 +22,7 @@ our @ObjectDependencies = (
     'Kernel::System::Encode',
     'Kernel::System::Log',
     'Kernel::System::Main',
+    'Kernel::System::SearchProfile',
     'Kernel::System::Time',
     'Kernel::System::Valid',
 );
@@ -276,12 +277,18 @@ sub GetUserData {
             my $TimeEnd = $TimeObject->TimeStamp2SystemTime(
                 String => $End,
             );
-            my $Till = int( ( $TimeEnd - $Time ) / 60 / 60 / 24 );
-            my $TillDate
-                = "$Preferences{OutOfOfficeEndYear}-$Preferences{OutOfOfficeEndMonth}-$Preferences{OutOfOfficeEndDay}";
             if ( $TimeStart < $Time && $TimeEnd > $Time ) {
-                $Preferences{OutOfOfficeMessage} = "*** out of office till $TillDate/$Till d ***";
-                $Data{UserFullname} .= ' ' . $Preferences{OutOfOfficeMessage};
+                my $OutOfOfficeMessageTemplate =
+                    $ConfigObject->Get('OutOfOfficeMessageTemplate') || '*** out of office until %s (%s d left) ***';
+                my $TillDate = sprintf(
+                    '%04d-%02d-%02d',
+                    $Preferences{OutOfOfficeEndYear},
+                    $Preferences{OutOfOfficeEndMonth},
+                    $Preferences{OutOfOfficeEndDay}
+                );
+                my $Till = int( ( $TimeEnd - $Time ) / 60 / 60 / 24 );
+                $Preferences{OutOfOfficeMessage} = sprintf( $OutOfOfficeMessageTemplate, $TillDate, $Till );
+                $Data{UserLastname} .= ' ' . $Preferences{OutOfOfficeMessage};
             }
 
             # Reduce CacheTTL to one hour for users that are out of office to make sure the cache expires timely
@@ -331,6 +338,7 @@ to add new users
         UserLogin     => 'mhuber',
         UserPw        => 'some-pass', # not required
         UserEmail     => 'email@example.com',
+        UserMobile    => '1234567890', # not required
         ValidID       => 1,
         ChangeUserID  => 123,
     );
@@ -345,7 +353,7 @@ sub UserAdd {
         if ( !$Param{$_} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -445,13 +453,17 @@ sub UserAdd {
         Value  => $Param{UserEmail}
     );
 
+    # set mobile phone
+    $Self->SetPreferences(
+        UserID => $UserID,
+        Key    => 'UserMobile',
+        Value  => $Param{UserMobile} || '',
+    );
+
     # delete cache
     $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => $Self->{CacheType},
     );
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => 'Group'
-    );
 
     return $UserID;
 }
@@ -467,6 +479,7 @@ to update users
         UserLogin     => 'mhuber',
         UserPw        => 'some-pass', # not required
         UserEmail     => 'email@example.com',
+        UserMobile    => '1234567890', # not required
         ValidID       => 1,
         ChangeUserID  => 123,
     );
@@ -481,13 +494,18 @@ sub UserUpdate {
         if ( !$Param{$_} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
     }
 
-    # check if a user with this login (username) already exits
+    # store old user login for later use
+    my $OldUserLogin = $Self->UserLookup(
+        UserID => $Param{UserID},
+    );
+
+    # check if a user with this login (username) already exists
     if (
         $Self->UserLoginExistsCheck(
             UserLogin => $Param{UserLogin},
@@ -528,12 +546,6 @@ sub UserUpdate {
         ],
     );
 
-    # log notice
-    $Kernel::OM->Get('Kernel::System::Log')->Log(
-        Priority => 'notice',
-        Message  => "User: '$Param{UserLogin}' updated successfully ($Param{ChangeUserID})!",
-    );
-
     # check pw
     if ( $Param{UserPw} ) {
         $Self->SetPassword(
@@ -549,8 +561,41 @@ sub UserUpdate {
         Value  => $Param{UserEmail}
     );
 
+    # set email address
+    $Self->SetPreferences(
+        UserID => $Param{UserID},
+        Key    => 'UserMobile',
+        Value  => $Param{UserMobile} || '',
+    );
+
+    # update search profiles if the UserLogin changed
+    if ( lc $OldUserLogin ne lc $Param{UserLogin} ) {
+        $Kernel::OM->Get('Kernel::System::SearchProfile')->SearchProfileUpdateUserLogin(
+            Base         => 'TicketSearch',
+            UserLogin    => $OldUserLogin,
+            NewUserLogin => $Param{UserLogin},
+        );
+    }
+
     $Self->_UserCacheClear( UserID => $Param{UserID} );
 
+    # TODO Not needed to delete the cache if ValidID or Name was not changed
+
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+    my $SystemPermissionConfig = $Kernel::OM->Get('Kernel::Config')->Get('System::Permission') || [];
+
+    for my $Type ( @{$SystemPermissionConfig}, 'rw' ) {
+
+        $CacheObject->Delete(
+            Type => 'GroupPermissionUserGet',
+            Key  => 'PermissionUserGet::' . $Param{UserID} . '::' . $Type,
+        );
+    }
+
+    $CacheObject->CleanUp(
+        Type => 'GroupPermissionGroupGet',
+    );
+
     return 1;
 }
 
@@ -829,10 +874,12 @@ user login or id lookup
 
     my $UserLogin = $UserObject->UserLookup(
         UserID => 1,
+        Silent => 1, # optional, don't generate log entry if user was not found
     );
 
     my $UserID = $UserObject->UserLookup(
         UserLogin => 'some_user_login',
+        Silent    => 1, # optional, don't generate log entry if user was not found
     );
 
 =cut
@@ -879,10 +926,12 @@ sub UserLookup {
         }
 
         if ( !$ID ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "No UserID found for '$Param{UserLogin}'!",
-            );
+            if ( !$Param{Silent} ) {
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message  => "No UserID found for '$Param{UserLogin}'!",
+                );
+            }
             return;
         }
 
@@ -922,10 +971,12 @@ sub UserLookup {
         }
 
         if ( !$Login ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "No UserLogin found for '$Param{UserID}'!",
-            );
+            if ( !$Param{Silent} ) {
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message  => "No UserLogin found for '$Param{UserID}'!",
+                );
+            }
             return;
         }
 
@@ -946,7 +997,7 @@ sub UserLookup {
 get user name
 
     my $Name = $UserObject->UserName(
-        User => 'some-login',
+        UserLogin => 'some-login',
     );
 
     or
@@ -972,8 +1023,8 @@ return a hash with all users
 
     my %List = $UserObject->UserList(
         Type          => 'Short', # Short|Long, default Short
-        Valid         => 1,       # not required, default 0
-        NoOutOfOffice => 1,       # optional, default 0
+        Valid         => 1,       # default 1
+        NoOutOfOffice => 1,       # (optional) default 0
     );
 
 =cut
@@ -1095,14 +1146,13 @@ generate a random password
 sub GenerateRandomPassword {
     my ( $Self, %Param ) = @_;
 
-    # Generated passwords are eight characters long by default.
+    # generated passwords are eight characters long by default.
     my $Size = $Param{Size} || 8;
 
     my $Password = $Kernel::OM->Get('Kernel::System::Main')->GenerateRandomString(
         Length => $Size,
     );
 
-    # Return the password.
     return $Password;
 }
 
@@ -1132,22 +1182,6 @@ sub SetPreferences {
         }
     }
 
-    # Don't allow overwriting of native user data.
-    my %Blacklisted = (
-        UserID        => 1,
-        UserLogin     => 1,
-        UserPw        => 1,
-        UserFirstname => 1,
-        UserLastname  => 1,
-        UserFullname  => 1,
-        UserTitle     => 1,
-        ChangeTime    => 1,
-        CreateTime    => 1,
-        ValidID       => 1,
-    );
-
-    return 0 if $Blacklisted{ $Param{Key} };
-
     # get current setting
     my %User = $Self->GetUserData(
         UserID        => $Param{UserID},
@@ -1437,7 +1471,7 @@ sub _UserFullname {
 
 =item UserLoginExistsCheck()
 
-return 1 if another user with this login (username) already exits
+return 1 if another user with this login (username) already exists
 
     $Exist = $UserObject->UserLoginExistsCheck(
         UserLogin => 'Some::UserLogin',
@@ -1477,10 +1511,10 @@ sub UserLoginExistsCheck {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
